@@ -1,14 +1,19 @@
 from validator.rules_src import Rule
 from validator.rules_src import __all__
-from validator.rules_src.IP import *
-from validator.rules_src.IPv4 import *
-from validator.rules_src.IPv6 import *
+from validator.rules_src.accepted import *
+from validator.rules_src.alpha import *
+from validator.rules_src.base32 import *
+from validator.rules_src.base64 import *
 from validator.rules_src.between import *
 from validator.rules_src.binary import *
 from validator.rules_src.date import *
 from validator.rules_src.decimal import *
+from validator.rules_src.dict import *
 from validator.rules_src.hex import *
 from validator.rules_src.integer import *
+from validator.rules_src.ip import *
+from validator.rules_src.ipv4 import *
+from validator.rules_src.ipv6 import *
 from validator.rules_src.json import *
 from validator.rules_src.list import *
 from validator.rules_src.mail import *
@@ -17,7 +22,10 @@ from validator.rules_src.min import *
 from validator.rules_src.octal import *
 from validator.rules_src.regex import *
 from validator.rules_src.required import *
+from validator.rules_src.required_if import *
 from validator.rules_src.same import *
 from validator.rules_src.size import *
 from validator.rules_src.string import *
+from validator.rules_src.uuidv1 import *
+from validator.rules_src.uuidv3 import *
 from validator.rules_src.uuidv4 import *
