@@ -4,7 +4,7 @@ from validator.rules_src import Rule
 
 class Mail(Rule):
     """
-    The field under validation must be formatted as an e-mail address 
+    The field under validation must be formatted as an e-mail address
 
     Examples:
     >>> from validator import validate
@@ -28,7 +28,7 @@ class Mail(Rule):
         if re.search(self.regex, arg) is not None:
             return True
 
-        self.set_errror_message(f"Expected a Mail, Got: {arg}")
+        self.set_error(f"Expected a Mail, Got: {arg}")
         return False
 
     def __from_str__(self):
