@@ -5,7 +5,7 @@ from validator import utils
 
 class Max(Rule):
     """
-    The field under validation must be less than or equal to a maximum value 
+    The field under validation must be less than or equal to a maximum value
     Given value is evaluated according to `Size` rule
 
     Examples:
@@ -29,12 +29,12 @@ class Max(Rule):
     def check(self, arg):
         # Evaluate to Size rule
         size = Size.size_value(arg, self.rpv)
-        if size == None:
-            self.set_errror_message(f"Could not get size from data. type = {type(arg)}")
+        if size is None:
+            self.set_error(f"Could not get size from data. type = {type(arg)}")
             return False
 
         if size > self.max:
-            self.set_errror_message(f"Expected Maximum: {self.max}, Got: {size}")
+            self.set_error(f"Expected Maximum: {self.max}, Got: {size}")
             return False
 
         return True
