@@ -29,11 +29,11 @@ class Min(Rule):
     def check(self, arg):
         # Evaluate to Size rule
         size = Size.size_value(arg, self.rpv)
-        if size == None:
-            self.set_errror_message(f"Could not get size from data. type = {type(arg)}")
+        if size is None:
+            self.set_error(f"Could not get size from data. type = {type(arg)}")
             return False
         if size < self.min:
-            self.set_errror_message(f"Expected Maximum: {self.min}, Got: {size}")
+            self.set_error(f"Expected Maximum: {self.min}, Got: {size}")
             return False
 
         return True
