@@ -24,6 +24,8 @@ class Octal(Rule):
     False
     """
 
+    aliases = ["oct", "octal"]
+
     def __init__(self):
         Rule.__init__(self)
 
@@ -34,9 +36,7 @@ class Octal(Rule):
             return True
         except:
             # if transfered to exception we know its not octal.
-            self.set_errror_message(
-                f"Expected String to be in Octal format, Got: {arg}"
-            )
+            self.set_error(f"Expected String to be in Octal format, Got: {arg}")
             return False
 
     @staticmethod
