@@ -3,7 +3,7 @@ from validator.rules_src import Rule
 
 class Required(Rule):
     """
-    The field under validation must be present in the input data and not empty 
+    The field under validation must be present in the input data and not empty
 
     Examples:
     >>> from validator import validate
@@ -24,7 +24,7 @@ class Required(Rule):
 
     def check(self, arg):
         if arg is None or (hasattr(arg, "__len__") and len(arg) == 0):
-            self.set_errror_message("Field was empty")
+            self.set_error("Field was empty")
             return False
         return True
 
